@@ -12,15 +12,14 @@
     WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     See the License for the specific language governing permissions and
     limitations under the License.
-
-
-
-
 */
 
 #ifndef __TBB_parallel_for_H
 #define __TBB_parallel_for_H
 
+#define __TBB_parallel_for_H_include_area
+#include "internal/_warning_suppress_enable_notice.h"
+
 #include <new>
 #include "task.h"
 #include "partitioner.h"
@@ -111,9 +110,9 @@ namespace internal {
         }
 #endif /* __TBB_TASK_GROUP_CONTEXT */
         //! Run body for range, serves as callback for partitioner
-        void run_body( Range &r ) { 
+        void run_body( Range &r ) {
             fgt_alg_begin_body( tbb::internal::PARALLEL_FOR_TASK, (void *)const_cast<Body*>(&(this->my_body)), (void*)this );
-            my_body( r ); 
+            my_body( r );
             fgt_alg_end_body( (void *)const_cast<Body*>(&(this->my_body)) );
         }
 
@@ -420,4 +419,7 @@ using strict_ppl::parallel_for;
 #undef __TBB_NORMAL_EXECUTION
 #endif
 
+#include "internal/_warning_suppress_disable_notice.h"
+#undef __TBB_parallel_for_H_include_area
+
 #endif /* __TBB_parallel_for_H */
